Unfortunately, the RMySQL driver will convert these to doubles because not all
unsigned ints are representable as ints. Because doubles get normalized, we
can't mask subnets directly.Instead, we can map the top half of unsigned integers to the negative half of signed
ints using 2s-complement.